Scenarios & stages
==================

Hierarchy
---------
The model supports ``period → scenario → stage`` as indices.
Stages can represent hours, representative periods, etc.

.. automodule:: vy4e_optmodel.scenarios
    :members:
